@@ -11,7 +11,7 @@ class Rank(template.Node):
         # Pasamos las variables a render
         self.usuario = template.Variable( usuario )
         self.numposts = template.Variable( numposts )
-        
+
     def render(self, context):
         # Comprobamos lo que valen en su contexto
         usuario = self.usuario.resolve( context )
@@ -19,7 +19,7 @@ class Rank(template.Node):
 
         # Seguimos con la lógica del filtro
         therank = mymodels.Rank.objects.get(limit_from__lte=numposts, limit_to__gte=numposts)
-        print therank
+        #print therank
         return therank
 
 @register.tag
